require 'spec_helper'

describe Solo do
  describe Solo::License do
    before(:each) { configure }

    it "Checks a valid license" do
      VCR.use_cassette('check_valid_license') do
        id = 1230
        license = subject::License.infocheck(id)
        license.should be_instance_of Hash
        license["ResultCode"].should == '0'
      end
    end

    it "Returns error on invalid license" do
      VCR.use_cassette('check_invalid_license') do
        id = 0
        license = subject::License.infocheck(id)
        license.should be_instance_of Hash
        license["ResultCode"].should == '100'
      end
    end

    it "Returns -2 on bad XML in the request" do
      VCR.use_cassette('check_badxml_license') do
        id = '<lol>'
        license = subject::License.infocheck(id)
        license.should be_instance_of Hash
        license["ResultCode"].should == '-2'
      end
    end

    it "Adds a valid license" do
      VCR.use_cassette('add_license') do
        license = subject::License.add(:ProdOptionID => '9754',
                                       :CustomerID => '20496203',
                                       :Expiration => '08/30/2012',
                                       :ActivationCount => '5')
        license.should be_instance_of Hash
        license["ResultCode"].should == '0'
      end
    end

    it "Fails to add an license with invalid product option" do
      VCR.use_cassette('add_blank_license') do
        license = subject::License.add(:ProdOptionID => '')
        license.should be_instance_of Hash
        license["ResultCode"].should == '1'
      end
    end

    it "Fails to add an invalid license" do
      VCR.use_cassette('add_invalid_license') do
        license = subject::License.add(:ProdOptionID => '<testinvaliddata>')
        license.should be_instance_of Hash
        license["ResultCode"].should == '-2'
      end
    end

  end
end
